@@ -24,7 +24,7 @@ int main (int argc, char const *const *argv)
   int unexport = 0 ;
   PROG = "s6-applyuidgid" ;
   {
-    subgetopt_t l = SUBGETOPT_ZERO ;
+    subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
     {
       int opt = subgetopt_r(argc, argv, "zUu:g:G:", &l) ;
